@@ -5,15 +5,19 @@ The handler collects data with [`pytkdocs`](https://github.com/pawamoy/pytkdocs)
 
 import json
 import os
+import posixpath
 import sys
 import traceback
 from collections import ChainMap
 from subprocess import PIPE, Popen  # noqa: S404 (what other option, more secure that PIPE do we have? sockets?)
-from typing import Any, List, Optional
+from typing import Any, BinaryIO, Callable, Iterator, List, Optional, Tuple
 
 from markdown import Markdown
+from markupsafe import Markup
 
+from mkdocstrings.extension import PluginError
 from mkdocstrings.handlers.base import BaseCollector, BaseHandler, BaseRenderer, CollectionError, CollectorItem
+from mkdocstrings.inventory import Inventory
 from mkdocstrings.loggers import get_logger
 
 log = get_logger(__name__)
@@ -43,8 +47,10 @@ class PythonRenderer(BaseRenderer):
         "show_if_no_docstring": False,
         "show_signature_annotations": False,
         "show_source": True,
+        "show_bases": True,
         "group_by_category": True,
         "heading_level": 2,
+        "members_order": "alphabetical",
     }
     """The default rendering options.
 
@@ -59,8 +65,10 @@ class PythonRenderer(BaseRenderer):
     **`show_if_no_docstring`** | `bool` | Show the object heading even if it has no docstring or children with docstrings. | `False`
     **`show_signature_annotations`** | `bool` | Show the type annotations in methods and functions signatures. | `False`
     **`show_source`** | `bool` | Show the source code of this object. | `True`
+    **`show_bases`** | `bool` | Show the base classes of a class. | `True`
     **`group_by_category`** | `bool` | Group the object's children by categories: attributes, classes, functions, methods, and modules. | `True`
     **`heading_level`** | `int` | The initial heading level to use. | `2`
+    **`members_order`** | `str` | The members ordering to use. Options: `alphabetical` - order by the members names, `source` - order members as they appear in the source file. | `alphabetical`
     """  # noqa: E501
 
     def render(self, data: CollectorItem, config: dict) -> str:  # noqa: D102 (ignore missing docstring)
@@ -72,6 +80,16 @@ class PythonRenderer(BaseRenderer):
         # of the rendering recursion. Therefore, it's easier to use it as a plain value
         # than as an item in a dictionary.
         heading_level = final_config["heading_level"]
+        members_order = final_config["members_order"]
+
+        if members_order == "alphabetical":
+            sort_function = _sort_key_alphabetical
+        elif members_order == "source":
+            sort_function = _sort_key_source
+        else:
+            raise PluginError(f"Unknown members_order '{members_order}', choose between 'alphabetical' and 'source'.")
+
+        sort_object(data, sort_function=sort_function)
 
         return template.render(
             **{"config": final_config, data["category"]: data, "heading_level": heading_level, "root": True},
@@ -85,6 +103,12 @@ class PythonRenderer(BaseRenderer):
         self.env.trim_blocks = True
         self.env.lstrip_blocks = True
         self.env.keep_trailing_newline = False
+        self.env.filters["brief_xref"] = self.do_brief_xref
+
+    def do_brief_xref(self, path: str) -> Markup:
+        """Filter to create cross-reference with brief text and full identifier as hover text."""
+        brief = path.split(".")[-1]
+        return Markup("<span data-autorefs-optional-hover={path}>{brief}</span>").format(path=path, brief=brief)
 
 
 class PythonCollector(BaseCollector):
@@ -152,7 +176,6 @@ class PythonCollector(BaseCollector):
         self.process = Popen(  # noqa: S603,S607 (we trust the input, and we don't want to use the absolute path)
             cmd,
             universal_newlines=True,
-            stderr=PIPE,
             stdout=PIPE,
             stdin=PIPE,
             bufsize=-1,
@@ -236,7 +259,39 @@ class PythonCollector(BaseCollector):
 
 
 class PythonHandler(BaseHandler):
-    """The Python handler class, nothing specific here."""
+    """The Python handler class.
+
+    Attributes:
+        domain: The cross-documentation domain/language for this handler.
+        enable_inventory: Whether this handler is interested in enabling the creation
+            of the `objects.inv` Sphinx inventory file.
+    """
+
+    domain: str = "py"  # to match Sphinx's default domain
+    enable_inventory: bool = True
+
+    @classmethod
+    def load_inventory(
+        cls, in_file: BinaryIO, url: str, base_url: Optional[str] = None, **kwargs
+    ) -> Iterator[Tuple[str, str]]:
+        """Yield items and their URLs from an inventory file streamed from `in_file`.
+
+        This implements mkdocstrings' `load_inventory` "protocol" (see plugin.py).
+
+        Arguments:
+            in_file: The binary file-like object to read the inventory from.
+            url: The URL that this file is being streamed from (used to guess `base_url`).
+            base_url: The URL that this inventory's sub-paths are relative to.
+            **kwargs: Ignore additional arguments passed from the config.
+
+        Yields:
+            Tuples of (item identifier, item URL).
+        """
+        if base_url is None:
+            base_url = posixpath.dirname(url)
+
+        for item in Inventory.parse_sphinx(in_file, domain_filter=("py",)).values():  # noqa: WPS526
+            yield item.name, posixpath.join(base_url, item.uri)
 
 
 def get_handler(
@@ -282,3 +337,36 @@ def rebuild_category_lists(obj: dict) -> None:
     obj["children"] = [child for _, child in obj["children"].items()]
     for child in obj["children"]:
         rebuild_category_lists(child)
+
+
+def sort_object(obj: CollectorItem, sort_function: Callable[[CollectorItem], Any]) -> None:
+    """Sort the collected object's children.
+
+    Sorts the object's children list, then each category separately, and then recurses into each.
+
+    Arguments:
+        obj: The collected object, as a dict. Note that this argument is mutated.
+        sort_function: The sort key function used to determine the order of elements.
+    """
+    obj["children"].sort(key=sort_function)
+
+    for category in ("attributes", "classes", "functions", "methods", "modules"):
+        obj[category].sort(key=sort_function)
+
+    for child in obj["children"]:
+        sort_object(child, sort_function=sort_function)
+
+
+def _sort_key_alphabetical(item: CollectorItem) -> Any:
+    """Return a sort key for 'alphabetical' sorting of CollectorItems."""
+    # chr(sys.maxunicode) is a string that contains the final unicode
+    # character, so if 'name' isn't found on the object, the item will go to
+    # the end of the list.
+    return item.get("name", chr(sys.maxunicode))
+
+
+def _sort_key_source(item: CollectorItem) -> Any:
+    """Return a sort key for 'source' sorting of CollectorItems."""
+    # if 'line_start' isn't found on the object, the item will go to
+    # the start of the list.
+    return item.get("source", {}).get("line_start", -1)
